km3pipe.io.HDF5Sink
===================

.. currentmodule:: km3pipe.io

.. autoclass:: HDF5Sink

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HDF5Sink.__init__
      ~HDF5Sink.add
      ~HDF5Sink.configure
      ~HDF5Sink.expose
      ~HDF5Sink.finish
      ~HDF5Sink.get
      ~HDF5Sink.pre_finish
      ~HDF5Sink.process
      ~HDF5Sink.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HDF5Sink.name
   
   